@@ -374,6 +374,24 @@ end
         @test !ishalfinteger(im)
     end
 
+    @testset "ishalfodd" begin
+        for T in (halfinttypes..., halfuinttypes..., :BigHalfInt)
+            @eval @test !ishalfodd($T(3))
+            @eval @test ishalfodd($T(5/2))
+        end
+        @test !ishalfodd(5)
+        @test !ishalfodd(big(-5))
+        @test ishalfodd(5//2)
+        @test ishalfodd(-3//2)
+        @test !ishalfodd(4//3)
+        @test !ishalfodd(2.0)
+        @test ishalfodd(-7.5)
+        @test !ishalfodd(2.3)
+        @test !ishalfodd(π)
+        @test !ishalfodd(ℯ)
+        @test !ishalfodd(im)
+    end
+
     @testset "isinteger" begin
         for T in (halfinttypes..., :BigHalfInt)
             @eval @test isinteger($T(3))
@@ -387,7 +405,7 @@ end
         end
     end
 
-    @static if VERSION ≥ v"1.6.0-DEV.999"
+    if VERSION ≥ v"1.6.0-DEV.999"
         @testset "ispow2" begin
             for T in (halfinttypes..., :BigHalfInt)
                 @eval @test ispow2($T(1/2))
@@ -812,7 +830,7 @@ end
             @eval @test @inferred(rem(big(4), BigHalfInt(3/2), $r)) isa BigHalfInt
             @eval @test @inferred(rem(big(4), HalfInt(3/2), $r)) isa BigHalfInt
         end
-        @static if VERSION ≥ v"1.4.0-DEV.208"
+        if VERSION ≥ v"1.4.0-DEV.208"
             for r in (:RoundNearest, :RoundNearestTiesAway, :RoundNearestTiesUp, :RoundToZero, :RoundUp, :RoundDown)
                 for T in (halfinttypes..., halfuinttypes..., :BigHalfInt)
                     @eval @test @inferred(div($T(7/2), $T(3/2), $r)) == div(7//2, 3//2, $r)
@@ -868,7 +886,7 @@ end
                 @eval @test @inferred(divrem(big(4), HalfInt(3/2), $r)) isa Tuple{BigInt,BigHalfInt}
             end
         end
-        @static if VERSION ≥ v"1.5.0-DEV.471"
+        if VERSION ≥ v"1.5.0-DEV.471"
             for (f,bigreturntype) in ((:rem, :BigHalfInt), (:divrem, :(Tuple{BigInt,BigHalfInt})))
                 for T in (halfinttypes..., :BigHalfInt)
                     @eval @test @inferred($f($T(7/2), $T(3/2), RoundNearest)) == $f(7//2, 3//2, RoundNearest)
@@ -1046,7 +1064,7 @@ end
         @test complex(BigHalfInt(-2))^HalfInt(5/2) ≈ √32*im
     end
 
-    @static if VERSION ≥ v"1.4.0-DEV.699"
+    if VERSION ≥ v"1.4.0-DEV.699"
         @testset "lcm/gcd/gcdx" begin
             @testset "Scalar-argument gcd/lcm" begin
                 for T in (halfinttypes..., halfuinttypes..., :BigHalfInt)
@@ -1522,34 +1540,41 @@ end
 end
 
 @testset "Trigonometry" begin
-    fs = @static if VERSION ≥ v"1.6.0-DEV.292"
-        (:sinpi, :cospi, :sincospi)
-    else
-        (:sinpi, :cospi)
+    function test_sinpi_cospi(x, _sinpi, _cospi)
+        @test isequal(sinpi(x), _sinpi)
+        @test isequal(cospi(x), _cospi)
+        @static if isdefined(Base, :sincospi)
+            @test isequal(sincospi(x), (_sinpi,_cospi))
+        end
     end
-    for f = fs
-        for T = inttypes
-            @eval xs = half.(Half{$T}, [0, 1, -2, 4, 5, -5,
-                                        typemax($T), typemax($T)-1, typemax($T)-2, typemax($T)-3,
-                                        typemin($T), typemin($T)+1, typemin($T)+2, typemin($T)+3])
-            @eval @test typeof(@inferred($f(zero(Half{$T})))) === typeof($f(zero(Rational{$T})))
-            for x = xs
-                @eval @test isequal($f($x), $f(Rational{BigInt}($x)))
-            end
+    for T = (inttypes..., uinttypes..., :BigInt)
+        @eval @test typeof(@inferred(sinpi(zero(Half{$T})))) == float(Half{$T})
+        @eval @test typeof(@inferred(cospi(zero(Half{$T})))) == float(Half{$T})
+        if isdefined(Base, :sincospi)
+            @eval @test typeof(@inferred(sincospi(zero(Half{$T})))) == NTuple{2, float(Half{$T})}
         end
-        for T = uinttypes
-            @eval xs = half.(Half{$T}, [0, 1, 2, 4, 5, 7,
-                                        typemax($T), typemax($T)-1, typemax($T)-2, typemax($T)-3])
-            @eval @test typeof(@inferred($f(zero(Half{$T})))) === typeof($f(zero(Rational{$T})))
-            for x = xs
-                @eval @test isequal($f($x), $f(Rational{BigInt}($x)))
-            end
+    end
+    for T = uinttypes
+        @eval xs = half.(Half{$T}, [0:7; typemax($T)-3:typemax($T)])
+        for (x,s,c) = zip(xs,
+                          [0.,1.,0.,-1.,0.,1.,0.,-1., 0.,1.,0.,-1.],
+                          [1.,0.,-1.,0.,1.,0.,-1.,0., 1.,0.,-1.,0.])
+            test_sinpi_cospi(x, s, c)
         end
-        @eval @test typeof(@inferred($f(zero(BigHalfInt)))) === typeof($f(zero(Rational{BigInt})))
-        for x = BigHalfInt[0, 1/2, 1, 2, 5/2, 7/2]
-            @eval @test isequal($f($x), $f(Rational{BigInt}($x)))
+    end
+    for T = inttypes
+        @eval xs = half.(Half{$T}, [typemin($T):typemin($T)+3; -5:5; typemax($T)-3:typemax($T)])
+        for (x,s,c) = zip(xs,
+                          [-0.,1.,-0.,-1., -1.,-0.,1.,-0.,-1., 0., 1.,0.,-1.,0.,1., 0.,1.,0.,-1.],
+                          [1.,0.,-1.,0., 0.,1.,0.,-1.,0., 1., 0.,-1.,0.,1.,0., 1.,0.,-1.,0.])
+            test_sinpi_cospi(x, s, c)
         end
     end
+    for (x,s,c) = zip(BigHalfInt[-7/2:1/2:7/2;],
+                      [1.,-0.,-1.,-0.,1.,-0.,-1., 0., 1., 0.,-1.,0.,1., 0.,-1.],
+                      [0.,-1.,0.,1.,0.,-1.,0., 1., 0.,-1.,0.,1.,0.,-1.,0.])
+        test_sinpi_cospi(x, s, c)
+    end
 end
 
 @testset "$f" for (f,eq) = ((:sinc,:isequal), (:cosc,:isapprox))
@@ -1683,6 +1708,7 @@ end
     @test onehalf(missing) === onehalf(Missing) === missing
 
     @test ishalfinteger(missing) === missing
+    @test ishalfodd(missing) === missing
 end
 
 include("ranges.jl")
